#
# spec file for package qmmp-plugin-pack
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2014 Dmitry Misharov <quarckster@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qmmp_ver_min 1.5.0
%define qmmp_ver_max 1.5.99
%define mver    1.5
Name:           qmmp-plugin-pack
Version:        1.5.1
Release:        pm153.6.3
Summary:        Extra plugins for Qmmp
License:        GPL-2.0-or-later
URL:            https://qmmp.ylsoftware.com/plugins.php
Source:         https://qmmp.ylsoftware.com/files/%{name}/%{mver}/%{name}-%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libqmmp-plugins <= %{qmmp_ver_max}
BuildRequires:  libqmmp-plugins >= %{qmmp_ver_min}
BuildRequires:  libqt5-qttools-devel >= 5.4
BuildRequires:  pkgconfig
BuildRequires:  yasm
BuildRequires:  pkgconfig(Qt5Core) >= 5.4
BuildRequires:  pkgconfig(Qt5Sql) >= 5.4
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.4
BuildRequires:  pkgconfig(libavcodec) >= 57.48.101
BuildRequires:  pkgconfig(libavformat) >= 57.40.101
BuildRequires:  pkgconfig(libavutil) >= 55.27.100
BuildRequires:  pkgconfig(libmpg123) >= 1.13.0
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale) >= 4.1.100
BuildRequires:  pkgconfig(libxmp)
BuildRequires:  pkgconfig(qmmp) <= %{qmmp_ver_max}
BuildRequires:  pkgconfig(qmmp) >= %{qmmp_ver_min}
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(taglib) >= 1.10
Requires:       qmmp <= %{qmmp_ver_max}
Requires:       qmmp >= %{qmmp_ver_min}
Obsoletes:      %{name}-history < %{version}
Obsoletes:      %{name}-mpg123 < %{version}
ExclusiveArch:  %ix86 x86_64

%description
This package contains extra plugins for Qmmp.

%package ffap
Summary:        Enhanced Monkey's Audio (APE) decoder for Qmmp
Requires:       %{name} = %{version}-%{release}

%description ffap
Enhanced Monkey's Audio (APE) decoder (24-bit samples and embedded
CUE support).

%package ffvideo
Summary:        Video Playback Qmmp plugin
Requires:       %{name} = %{version}-%{release}

%description ffvideo
Qmmp plugin to play videos.

%package goom
Summary:        Goom visualisation Qmmp plugin
Requires:       %{name} = %{version}-%{release}

%description goom
Qmmp plugin which provides goom visualisation.

%package samplerate
Summary:        Qmmp plugin which uses libsamplerate for decoding
Requires:       %{name} = %{version}-%{release}

%description samplerate
Qmmp plugin which uses libsamplerate resampling library.

%package xmp
Summary:        Qmmp plugin which uses the libxmp module library
Requires:       %{name} = %{version}-%{release}

%description xmp
Qmmp plugin which uses libxmp to play module and tracker files.

%package youtube
Summary:        Qmmp plugin which uses the youtube-dl tool
Requires:       %{name} = %{version}-%{release}
Requires:       youtube-dl

%description youtube
Qmmp plugin which uses youtube-dl to stream videos.

%prep
%autosetup

%build
%cmake \
  -DCMAKE_BUILD_WITH_INSTALL_RPATH=ON \
  -DLIB_DIR=%{_lib}
%cmake_build

%install
%cmake_install

%files
%license COPYING
%doc AUTHORS ChangeLog README
%dir %{_libdir}/qmmp-%{mver}/
%{_datadir}/metainfo/%{name}.appdata.xml

%files ffap
%dir %{_libdir}/qmmp-%{mver}/Input/
%{_libdir}/qmmp-%{mver}/Input/libffap.so

%files ffvideo
%dir %{_libdir}/qmmp-%{mver}/Engines/
%{_libdir}/qmmp-%{mver}/Engines/libffvideo.so

%files goom
%dir %{_libdir}/qmmp-%{mver}/Visual/
%{_libdir}/qmmp-%{mver}/Visual/libgoom.so

%files samplerate
%dir %{_libdir}/qmmp-%{mver}/Effect/
%{_libdir}/qmmp-%{mver}/Effect/libsrconverter.so

%files xmp
%dir %{_libdir}/qmmp-%{mver}/Input/
%{_libdir}/qmmp-%{mver}/Input/libxmp.so

%files youtube
%dir %{_libdir}/qmmp-%{mver}/Transports
%{_libdir}/qmmp-%{mver}/Transports/libytb.so

%changelog
* Mon Jul 12 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.5.1
  * added Korean translation
* Sat Jul  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.5.0
  * ported to qmmp 1.5 API
  * added Youtube stream seeking
  * updated Dutch, Finnish, French, Galician, German, Greek, Italian,
    Indonesian, Polish, Portuguese, Russian, Spanish, and
    Ukrainian translations
* Thu Apr 30 2020 aloisio@gmx.com
- Update to version 1.4.0
  * ported to qmmp 1.4 api
  * added Youtube plugin (uses youtube-dl)
  * improved ffap plugin
  * updated Portuguese, Dutch, Polish, Galician, Spanish,
    Russian, Ukrainian, French, Indonesian, Greek, Italian,
    German
* Thu Mar 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.3.2 (changes since 1.3.0):
  * Fix Qt 5.5 support.
  * Fix an issue with missing properties for CUE tracks in the ffap
    plugin.
  * Fix a CMake warning.
  * Update translations.
- Drop support for old openSUSE versions.
* Thu Apr  4 2019 olaf@aepfle.de
- Use gcc8 in SLE_12
* Tue Feb 12 2019 sor.alexei@meowr.ru
- Update to version 1.3.0:
  * Port to Qmmp 1.3 API.
  * Improve ffvideo plugin.
  * Remove history and mpg123 plugins.
  * Update translations.
- Remove qmmp-libswresample.patch.
* Mon Nov 12 2018 olaf@aepfle.de
- Fix version for taglib and mpg123
- Add ffvideo pkg and fix build with qmmp-libswresample.patch
- All modules depend on main package to avoid stale pkgs in the future.
* Sun Nov 11 2018 olaf@aepfle.de
- ExclusiveArch x86 because ARM lacks projectM-Qt5
* Sat Sep 22 2018 sor.alexei@meowr.ru
- Update to version 1.2.3:
  * Fix gcc 8.1 support.
* Sat Jul 21 2018 sor.alexei@meowr.ru
- Update to version 1.2.2:
  * Fix the Goom plugin:
    + fix a segmentation fault;
    + fix an issue with gcc optimisations (the -O2 flag).
* Thu Apr 19 2018 sor.alexei@meowr.ru
- Update to version 1.2.1:
  * Add ffmpeg 4.0 support to the ffvideo plugin.
  * Fix issues with some corrupted files in the mpg123 plugin.
  * Updated translations.
* Fri Mar  2 2018 jengelh@inai.de
- Fix RPM groups and descriptions.
* Sun Nov 26 2017 sor.alexei@meowr.ru
- Update to version 1.2.0:
  * Port to the Qmmp 1.2 API.
  * Add history, ffvideo plugins.
  * Add Goom visualisation.
  * Fix memory leaks.
  * Add a Finnish translation.
  * Updated Brazilian Portuguese, Czech, Chinese Simplified,
    French, Galician, German, Greek, Polish, Portuguese, Russian,
    Spanish, Japanese, Ukrainian translations.
- Drop qmmp-plugin-pack-taglib-1.9.patch.
* Sun Oct 22 2017 sor.alexei@meowr.ru
- Update to version 1.1.5:
  * Add album artist tag support in the ffap plugin.
  * Fix cmake 3.10 support.
  * Fix rusxmms support in the mpg123 plugin.
  * Update Greek, Spanish translation.
* Fri Aug  4 2017 sor.alexei@meowr.ru
- Update to version 1.1.4:
  * Fix a possible segmentation fault in the mpg123 plugin.
  * Fix MP3 in WAV container detection in the mpg123 plugin.
  * Fix Russian translation.
  * Update Galician translation.
* Wed Oct  5 2016 sor.alexei@meowr.ru
- Update to version 1.1.3:
  * Fix 24 bits support in the ffap plugin.
* Fri Aug 26 2016 sor.alexei@meowr.ru
- Update to version 1.1.2:
  * Update Brazilian Portuguese translation.
* Mon Jul  4 2016 sor.alexei@meowr.ru
- Update to version 1.1.1:
  * Fix Qt 5.7 support.
  * Update German translation.
* Tue Jun 21 2016 sor.alexei@meowr.ru
- Update to version 1.1.0:
  * Port to Qmmp 1.1 API.
  * Add libsamplerate-based resampler.
  * Change default settings in the mpg123 plugin.
  * Update Bulgarian translation, Chinese Traditional,
    Chinese Simplified, French, German, Greek, Hebrew, Japanese,
    Portuguese, Russian, Ukrainian.
- Add qmmp-plugin-pack-taglib-1.9.patch: extend TagLib support to
  1.9 to support openSUSE 13.2 and Leap 42.1.
* Tue May 31 2016 sor.alexei@meowr.ru
- Update to version 1.0.4:
  * Fix TagLib-1.9 support.
- Remove fix_taglib_detection.patch: fixed upstream.
* Sun May  8 2016 aloisio@gmx.com
- Added fix_taglib_detection.patch to address a problem
  with taglib 1.10
* Tue May  3 2016 sor.alexei@meowr.ru
- Update to version 1.0.3:
  * Update Chinese Traditional, French, Hebrew translations.
* Mon Dec 21 2015 sor.alexei@meowr.ru
- Update to 1.0.2:
  * Fix build.
  * Fix cover art support in the mpg123 plugin.
  * Update Russian translation.
* Wed Nov  4 2015 sor.alexei@meowr.ru
- Update to 1.0.1 (changes since 0.9.2):
  * Port to Qmmp 1.0 API.
  * Switch to Qt5.
- Switch to Qt5.
* Sat Oct 10 2015 sor.alexei@meowr.ru
- Update to 0.9.2:
  * Fix build.
  * Reduce tag reading delay in the ffap plugin.
- Delete qmmp-plugin-pack-0.9.0-fix-xmp-include.patch: fixed
  upstream.
* Fri Oct  2 2015 sor.alexei@meowr.ru
- Update to 0.9.1:
  * Fix buffer overflow in the mpg123 plugin.
* Sun Sep  6 2015 sor.alexei@meowr.ru
- Update to 0.9.0 (changes since 0.8.4):
  * Fix cmake support.
  * Fix qsui plugin:
    + Fix problem with "jumping" slider.
    + Restore maximized mode after hide/show cycle.
    + Write settings when main window hides.
  * Fix documentation.
  * Port to Qmmp 0.9 api.
  * Add xmp plugin.
  * Add album artist tag support to the mpg123 plugin.
  * Add feature to disable plugins without qmmp-plugin-pack.pri
    modification (qmake only).
  * Remove qsui plugin.
  * Improve cmake build scripts.
  * Update Russian, Czech, Hebrew, German, Portuguese, Ukrainian,
    French, Polish, Greek, Japanese translations.
- Drop qmmp-plugin-pack-simple-ui as plugin is merged to
  libqmmp0-plugins.
- Do not force UNIX permissions in %%files globally.
- Add qmmp-plugin-pack-0.9.0-fix-xmp-include.patch.
- Spec cleanup.
* Tue Jun  9 2015 quarckster@gmail.com
- Update to 0.8.4
  * fixed qsui plugin:
  * fixed Ukrainian translation;
  * fixed custom color scheme usage;
  * optimized playlist drawing;
  * improved cover scaling quality;
  * fixed clang warnings in the ffap plugin.
* Tue Jan  6 2015 quarckster@gmail.com
- Update to 0.8.3
  * fixed qsui plugin:
  * fixed displaying of the symbol '&' in the tab name;
  * fixed displaying name of the current directory.
* Tue Oct 14 2014 quarckster@gmail.com
- Update to 0.8.2
  * added Portuguese translation;
  * added transifex integration;
  * added feature to create a new playlist on double click in the qsui plugin;
  * improved image scaling quality;
  * fixed color settings in the qsui plugin;
  * reduced tag reading delay in the mpg123 plugin.
* Wed Sep 17 2014 quarckster@gmail.com
- New package. Version 0.8.1
